@@ -1,10 +1,8 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-__all__ = ['affinegap',
-           'blocking',
+__all__ = ['blocking',
            'clustering',
            'core',
-           'lr',
            'backport',
            'predicates',
            'crossvalidation',
